a =
  b
    & c .~ d
    & e
      %~ f
        g
